==> ruby-vtk_0.1.1.orig.tar.gz: ruby-vtk-0.1.1.orig/Imaging/Imaging.cxx <==
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  if !defined(STATIC_LINKED)
#    define SWIGEXPORT(a) __declspec(dllexport) a
#  else
#    define SWIGEXPORT(a) a
#  endif
#else
#  define SWIGEXPORT(a) a
#endif


#ifdef __cplusplus
extern "C" {
#endif
extern SWIGEXPORT(void) Init_vtkImagingInstantiator(void);
extern SWIGEXPORT(void) Init_vtkBooleanTexture(void);
extern SWIGEXPORT(void) Init_vtkExtractVOI(void);
extern SWIGEXPORT(void) Init_vtkGaussianSplatter(void);
extern SWIGEXPORT(void) Init_vtkImageAccumulate(void);
extern SWIGEXPORT(void) Init_vtkImageAppend(void);
extern SWIGEXPORT(void) Init_vtkImageAppendComponents(void);
extern SWIGEXPORT(void) Init_vtkImageBlend(void);
extern SWIGEXPORT(void) Init_vtkImageButterworthHighPass(void);
extern SWIGEXPORT(void) Init_vtkImageButterworthLowPass(void);
extern SWIGEXPORT(void) Init_vtkImageCacheFilter(void);
extern SWIGEXPORT(void) Init_vtkImageCanvasSource2D(void);
extern SWIGEXPORT(void) Init_vtkImageCast(void);
extern SWIGEXPORT(void) Init_vtkImageChangeInformation(void);
extern SWIGEXPORT(void) Init_vtkImageCheckerboard(void);
extern SWIGEXPORT(void) Init_vtkImageClip(void);
extern SWIGEXPORT(void) Init_vtkImageConnector(void);
extern SWIGEXPORT(void) Init_vtkImageConvolve(void);
extern SWIGEXPORT(void) Init_vtkImageCorrelation(void);
extern SWIGEXPORT(void) Init_vtkImageCursor3D(void);
extern SWIGEXPORT(void) Init_vtkImageDataStreamer(void);
extern SWIGEXPORT(void) Init_vtkImageDifference(void);
extern SWIGEXPORT(void) Init_vtkImageDivergence(void);
extern SWIGEXPORT(void) Init_vtkImageDotProduct(void);
extern SWIGEXPORT(void) Init_vtkImageEllipsoidSource(void);
extern SWIGEXPORT(void) Init_vtkImageEuclideanToPolar(void);
extern SWIGEXPORT(void) Init_vtkImageExport(void);
extern SWIGEXPORT(void) Init_vtkImageExtractComponents(void);
extern SWIGEXPORT(void) Init_vtkImageGaussianSmooth(void);
extern SWIGEXPORT(void) Init_vtkImageGaussianSource(void);
extern SWIGEXPORT(void) Init_vtkImageGradient(void);
extern SWIGEXPORT(void) Init_vtkImageGradientMagnitude(void);
extern SWIGEXPORT(void) Init_vtkImageGridSource(void);
extern SWIGEXPORT(void) Init_vtkImageHSVToRGB(void);
extern SWIGEXPORT(void) Init_vtkImageIdealHighPass(void);
extern SWIGEXPORT(void) Init_vtkImageIdealLowPass(void);
extern SWIGEXPORT(void) Init_vtkImageImport(void);
extern SWIGEXPORT(void) Init_vtkImageIslandRemoval2D(void);
extern SWIGEXPORT(void) Init_vtkImageIterateFilter(void);
extern SWIGEXPORT(void) Init_vtkImageLaplacian(void);
extern SWIGEXPORT(void) Init_vtkImageLogarithmicScale(void);
extern SWIGEXPORT(void) Init_vtkImageLogic(void);
extern SWIGEXPORT(void) Init_vtkImageLuminance(void);
extern SWIGEXPORT(void) Init_vtkImageMagnify(void);
extern SWIGEXPORT(void) Init_vtkImageMagnitude(void);
extern SWIGEXPORT(void) Init_vtkImageMandelbrotSource(void);
extern SWIGEXPORT(void) Init_vtkImageMapToColors(void);
extern SWIGEXPORT(void) Init_vtkImageMapToRGBA(void);
extern SWIGEXPORT(void) Init_vtkImageMapToWindowLevelColors(void);
extern SWIGEXPORT(void) Init_vtkImageMask(void);
extern SWIGEXPORT(void) Init_vtkImageMaskBits(void);
extern SWIGEXPORT(void) Init_vtkImageMathematics(void);
extern SWIGEXPORT(void) Init_vtkImageNoiseSource(void);
extern SWIGEXPORT(void) Init_vtkImageNonMaximumSuppression(void);
extern SWIGEXPORT(void) Init_vtkImageNormalize(void);
extern SWIGEXPORT(void) Init_vtkImageOpenClose3D(void);
extern SWIGEXPORT(void) Init_vtkImagePadFilter(void);
extern SWIGEXPORT(void) Init_vtkImageQuantizeRGBToIndex(void);
extern SWIGEXPORT(void) Init_vtkImageRGBToHSV(void);
extern SWIGEXPORT(void) Init_vtkImageRectilinearWipe(void);
extern SWIGEXPORT(void) Init_vtkImageReslice(void);
extern SWIGEXPORT(void) Init_vtkImageSeedConnectivity(void);
extern SWIGEXPORT(void) Init_vtkImageShiftScale(void);
extern SWIGEXPORT(void) Init_vtkImageShrink3D(void);
extern SWIGEXPORT(void) Init_vtkImageSinusoidSource(void);
extern SWIGEXPORT(void) Init_vtkImageSkeleton2D(void);
extern SWIGEXPORT(void) Init_vtkImageSpatialFilter(void);
extern SWIGEXPORT(void) Init_vtkImageStencil(void);
extern SWIGEXPORT(void) Init_vtkImageStencilData(void);
extern SWIGEXPORT(void) Init_vtkImageStencilSource(void);
extern SWIGEXPORT(void) Init_vtkImageThreshold(void);
extern SWIGEXPORT(void) Init_vtkImageToImageStencil(void);
extern SWIGEXPORT(void) Init_vtkImageTranslateExtent(void);
extern SWIGEXPORT(void) Init_vtkImageVariance3D(void);
extern SWIGEXPORT(void) Init_vtkImageWrapPad(void);
extern SWIGEXPORT(void) Init_vtkImplicitFunctionToImageStencil(void);
extern SWIGEXPORT(void) Init_vtkPointLoad(void);
extern SWIGEXPORT(void) Init_vtkSampleFunction(void);
extern SWIGEXPORT(void) Init_vtkShepardMethod(void);
extern SWIGEXPORT(void) Init_vtkSimpleImageFilterExample(void);
extern SWIGEXPORT(void) Init_vtkSurfaceReconstructionFilter(void);
extern SWIGEXPORT(void) Init_vtkTriangularTexture(void);
extern SWIGEXPORT(void) Init_vtkVoxelModeller(void);
extern SWIGEXPORT(void) Init_vtkImageAnisotropicDiffusion2D(void);
extern SWIGEXPORT(void) Init_vtkImageAnisotropicDiffusion3D(void);
extern SWIGEXPORT(void) Init_vtkImageConstantPad(void);
extern SWIGEXPORT(void) Init_vtkImageContinuousDilate3D(void);
extern SWIGEXPORT(void) Init_vtkImageContinuousErode3D(void);
extern SWIGEXPORT(void) Init_vtkImageDecomposeFilter(void);
extern SWIGEXPORT(void) Init_vtkImageDilateErode3D(void);
extern SWIGEXPORT(void) Init_vtkImageEuclideanDistance(void);
extern SWIGEXPORT(void) Init_vtkImageFlip(void);
extern SWIGEXPORT(void) Init_vtkImageFourierCenter(void);
extern SWIGEXPORT(void) Init_vtkImageFourierFilter(void);
extern SWIGEXPORT(void) Init_vtkImageHybridMedian2D(void);
extern SWIGEXPORT(void) Init_vtkImageMedian3D(void);
extern SWIGEXPORT(void) Init_vtkImageMirrorPad(void);
extern SWIGEXPORT(void) Init_vtkImagePermute(void);
extern SWIGEXPORT(void) Init_vtkImageRFFT(void);
extern SWIGEXPORT(void) Init_vtkImageRange3D(void);
extern SWIGEXPORT(void) Init_vtkImageResample(void);
extern SWIGEXPORT(void) Init_vtkImageSeparableConvolution(void);
extern SWIGEXPORT(void) Init_vtkImageSobel2D(void);
extern SWIGEXPORT(void) Init_vtkImageSobel3D(void);
extern SWIGEXPORT(void) Init_vtkImageCityBlockDistance(void);
extern SWIGEXPORT(void) Init_vtkImageFFT(void);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT(void) Init_Imaging(void){

  Init_vtkImagingInstantiator();
  Init_vtkBooleanTexture();
  Init_vtkExtractVOI();
  Init_vtkGaussianSplatter();
  Init_vtkImageAccumulate();
  Init_vtkImageAppend();
  Init_vtkImageAppendComponents();
  Init_vtkImageBlend();
  Init_vtkImageButterworthHighPass();
  Init_vtkImageButterworthLowPass();
  Init_vtkImageCacheFilter();
  Init_vtkImageCanvasSource2D();
  Init_vtkImageCast();
  Init_vtkImageChangeInformation();
  Init_vtkImageCheckerboard();
  Init_vtkImageClip();
  Init_vtkImageConnector();
  Init_vtkImageConvolve();
  Init_vtkImageCorrelation();
  Init_vtkImageCursor3D();
  Init_vtkImageDataStreamer();
  Init_vtkImageDifference();
  Init_vtkImageDivergence();
  Init_vtkImageDotProduct();
  Init_vtkImageEllipsoidSource();
  Init_vtkImageEuclideanToPolar();
  Init_vtkImageExport();
  Init_vtkImageExtractComponents();
  Init_vtkImageGaussianSmooth();
  Init_vtkImageGaussianSource();
  Init_vtkImageGradient();
  Init_vtkImageGradientMagnitude();
  Init_vtkImageGridSource();
  Init_vtkImageHSVToRGB();
  Init_vtkImageIdealHighPass();
  Init_vtkImageIdealLowPass();
  Init_vtkImageImport();
  Init_vtkImageIslandRemoval2D();
  Init_vtkImageIterateFilter();
  Init_vtkImageLaplacian();
  Init_vtkImageLogarithmicScale();
  Init_vtkImageLogic();
  Init_vtkImageLuminance();
  Init_vtkImageMagnify();
  Init_vtkImageMagnitude();
  Init_vtkImageMandelbrotSource();
  Init_vtkImageMapToColors();
  Init_vtkImageMapToRGBA();
  Init_vtkImageMapToWindowLevelColors();
  Init_vtkImageMask();
  Init_vtkImageMaskBits();
  Init_vtkImageMathematics();
  Init_vtkImageNoiseSource();
  Init_vtkImageNonMaximumSuppression();
  Init_vtkImageNormalize();
  Init_vtkImageOpenClose3D();
  Init_vtkImagePadFilter();
  Init_vtkImageQuantizeRGBToIndex();
  Init_vtkImageRGBToHSV();
  Init_vtkImageRectilinearWipe();
  Init_vtkImageReslice();
  Init_vtkImageSeedConnectivity();
  Init_vtkImageShiftScale();
  Init_vtkImageShrink3D();
  Init_vtkImageSinusoidSource();
  Init_vtkImageSkeleton2D();
  Init_vtkImageSpatialFilter();
  Init_vtkImageStencil();
  Init_vtkImageStencilData();
  Init_vtkImageStencilSource();
  Init_vtkImageThreshold();
  Init_vtkImageToImageStencil();
  Init_vtkImageTranslateExtent();
  Init_vtkImageVariance3D();
  Init_vtkImageWrapPad();
  Init_vtkImplicitFunctionToImageStencil();
  Init_vtkPointLoad();
  Init_vtkSampleFunction();
  Init_vtkShepardMethod();
  Init_vtkSimpleImageFilterExample();
  Init_vtkSurfaceReconstructionFilter();
  Init_vtkTriangularTexture();
  Init_vtkVoxelModeller();
  Init_vtkImageAnisotropicDiffusion2D();
  Init_vtkImageAnisotropicDiffusion3D();
  Init_vtkImageConstantPad();
  Init_vtkImageContinuousDilate3D();
  Init_vtkImageContinuousErode3D();
  Init_vtkImageDecomposeFilter();
  Init_vtkImageDilateErode3D();
  Init_vtkImageEuclideanDistance();
  Init_vtkImageFlip();
  Init_vtkImageFourierCenter();
  Init_vtkImageFourierFilter();
  Init_vtkImageHybridMedian2D();
  Init_vtkImageMedian3D();
  Init_vtkImageMirrorPad();
  Init_vtkImagePermute();
  Init_vtkImageRFFT();
  Init_vtkImageRange3D();
  Init_vtkImageResample();
  Init_vtkImageSeparableConvolution();
  Init_vtkImageSobel2D();
  Init_vtkImageSobel3D();
  Init_vtkImageCityBlockDistance();
  Init_vtkImageFFT();
}

==> ruby-vtk_0.2.0.orig.tar.gz: ruby-vtk-0.2.0.orig/Imaging/Imaging.cxx <==
#if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#  if !defined(STATIC_LINKED)
#    define SWIGEXPORT(a) __declspec(dllexport) a
#  else
#    define SWIGEXPORT(a) a
#  endif
#else
#  define SWIGEXPORT(a) a
#endif


#ifdef __cplusplus
extern "C" {
#endif
extern SWIGEXPORT(void) Init_vtkImagingInstantiator(void);
extern SWIGEXPORT(void) Init_vtkBooleanTexture(void);
extern SWIGEXPORT(void) Init_vtkExtractVOI(void);
extern SWIGEXPORT(void) Init_vtkGaussianSplatter(void);
extern SWIGEXPORT(void) Init_vtkImageAccumulate(void);
extern SWIGEXPORT(void) Init_vtkImageAppend(void);
extern SWIGEXPORT(void) Init_vtkImageAppendComponents(void);
extern SWIGEXPORT(void) Init_vtkImageBlend(void);
extern SWIGEXPORT(void) Init_vtkImageButterworthHighPass(void);
extern SWIGEXPORT(void) Init_vtkImageButterworthLowPass(void);
extern SWIGEXPORT(void) Init_vtkImageCacheFilter(void);
extern SWIGEXPORT(void) Init_vtkImageCanvasSource2D(void);
extern SWIGEXPORT(void) Init_vtkImageCast(void);
extern SWIGEXPORT(void) Init_vtkImageChangeInformation(void);
extern SWIGEXPORT(void) Init_vtkImageCheckerboard(void);
extern SWIGEXPORT(void) Init_vtkImageClip(void);
extern SWIGEXPORT(void) Init_vtkImageConnector(void);
extern SWIGEXPORT(void) Init_vtkImageConvolve(void);
extern SWIGEXPORT(void) Init_vtkImageCorrelation(void);
extern SWIGEXPORT(void) Init_vtkImageCursor3D(void);
extern SWIGEXPORT(void) Init_vtkImageDataStreamer(void);
extern SWIGEXPORT(void) Init_vtkImageDifference(void);
extern SWIGEXPORT(void) Init_vtkImageDivergence(void);
extern SWIGEXPORT(void) Init_vtkImageDotProduct(void);
extern SWIGEXPORT(void) Init_vtkImageEllipsoidSource(void);
extern SWIGEXPORT(void) Init_vtkImageEuclideanToPolar(void);
extern SWIGEXPORT(void) Init_vtkImageExport(void);
extern SWIGEXPORT(void) Init_vtkImageExtractComponents(void);
extern SWIGEXPORT(void) Init_vtkImageGaussianSmooth(void);
extern SWIGEXPORT(void) Init_vtkImageGaussianSource(void);
extern SWIGEXPORT(void) Init_vtkImageGradient(void);
extern SWIGEXPORT(void) Init_vtkImageGradientMagnitude(void);
extern SWIGEXPORT(void) Init_vtkImageGridSource(void);
extern SWIGEXPORT(void) Init_vtkImageHSIToRGB(void);
extern SWIGEXPORT(void) Init_vtkImageHSVToRGB(void);
extern SWIGEXPORT(void) Init_vtkImageIdealHighPass(void);
extern SWIGEXPORT(void) Init_vtkImageIdealLowPass(void);
extern SWIGEXPORT(void) Init_vtkImageImport(void);
extern SWIGEXPORT(void) Init_vtkImageIslandRemoval2D(void);
extern SWIGEXPORT(void) Init_vtkImageIterateFilter(void);
extern SWIGEXPORT(void) Init_vtkImageLaplacian(void);
extern SWIGEXPORT(void) Init_vtkImageLogarithmicScale(void);
extern SWIGEXPORT(void) Init_vtkImageLogic(void);
extern SWIGEXPORT(void) Init_vtkImageLuminance(void);
extern SWIGEXPORT(void) Init_vtkImageMagnify(void);
extern SWIGEXPORT(void) Init_vtkImageMagnitude(void);
extern SWIGEXPORT(void) Init_vtkImageMandelbrotSource(void);
extern SWIGEXPORT(void) Init_vtkImageMapToColors(void);
extern SWIGEXPORT(void) Init_vtkImageMapToRGBA(void);
extern SWIGEXPORT(void) Init_vtkImageMapToWindowLevelColors(void);
extern SWIGEXPORT(void) Init_vtkImageMask(void);
extern SWIGEXPORT(void) Init_vtkImageMaskBits(void);
extern SWIGEXPORT(void) Init_vtkImageMathematics(void);
extern SWIGEXPORT(void) Init_vtkImageNoiseSource(void);
extern SWIGEXPORT(void) Init_vtkImageNonMaximumSuppression(void);
extern SWIGEXPORT(void) Init_vtkImageNormalize(void);
extern SWIGEXPORT(void) Init_vtkImageOpenClose3D(void);
extern SWIGEXPORT(void) Init_vtkImagePadFilter(void);
extern SWIGEXPORT(void) Init_vtkImageQuantizeRGBToIndex(void);
extern SWIGEXPORT(void) Init_vtkImageRGBToHSI(void);
extern SWIGEXPORT(void) Init_vtkImageRGBToHSV(void);
extern SWIGEXPORT(void) Init_vtkImageRectilinearWipe(void);
extern SWIGEXPORT(void) Init_vtkImageReslice(void);
extern SWIGEXPORT(void) Init_vtkImageSeedConnectivity(void);
extern SWIGEXPORT(void) Init_vtkImageShiftScale(void);
extern SWIGEXPORT(void) Init_vtkImageShrink3D(void);
extern SWIGEXPORT(void) Init_vtkImageSinusoidSource(void);
extern SWIGEXPORT(void) Init_vtkImageSkeleton2D(void);
extern SWIGEXPORT(void) Init_vtkImageSpatialFilter(void);
extern SWIGEXPORT(void) Init_vtkImageStencil(void);
extern SWIGEXPORT(void) Init_vtkImageStencilData(void);
extern SWIGEXPORT(void) Init_vtkImageStencilSource(void);
extern SWIGEXPORT(void) Init_vtkImageThreshold(void);
extern SWIGEXPORT(void) Init_vtkImageToImageStencil(void);
extern SWIGEXPORT(void) Init_vtkImageTranslateExtent(void);
extern SWIGEXPORT(void) Init_vtkImageVariance3D(void);
extern SWIGEXPORT(void) Init_vtkImageWrapPad(void);
extern SWIGEXPORT(void) Init_vtkImplicitFunctionToImageStencil(void);
extern SWIGEXPORT(void) Init_vtkPointLoad(void);
extern SWIGEXPORT(void) Init_vtkSampleFunction(void);
extern SWIGEXPORT(void) Init_vtkShepardMethod(void);
extern SWIGEXPORT(void) Init_vtkSimpleImageFilterExample(void);
extern SWIGEXPORT(void) Init_vtkSurfaceReconstructionFilter(void);
extern SWIGEXPORT(void) Init_vtkTriangularTexture(void);
extern SWIGEXPORT(void) Init_vtkVoxelModeller(void);
extern SWIGEXPORT(void) Init_vtkImageAnisotropicDiffusion2D(void);
extern SWIGEXPORT(void) Init_vtkImageAnisotropicDiffusion3D(void);
extern SWIGEXPORT(void) Init_vtkImageConstantPad(void);
extern SWIGEXPORT(void) Init_vtkImageContinuousDilate3D(void);
extern SWIGEXPORT(void) Init_vtkImageContinuousErode3D(void);
extern SWIGEXPORT(void) Init_vtkImageDecomposeFilter(void);
extern SWIGEXPORT(void) Init_vtkImageDilateErode3D(void);
extern SWIGEXPORT(void) Init_vtkImageEuclideanDistance(void);
extern SWIGEXPORT(void) Init_vtkImageFlip(void);
extern SWIGEXPORT(void) Init_vtkImageFourierCenter(void);
extern SWIGEXPORT(void) Init_vtkImageFourierFilter(void);
extern SWIGEXPORT(void) Init_vtkImageHybridMedian2D(void);
extern SWIGEXPORT(void) Init_vtkImageMedian3D(void);
extern SWIGEXPORT(void) Init_vtkImageMirrorPad(void);
extern SWIGEXPORT(void) Init_vtkImagePermute(void);
extern SWIGEXPORT(void) Init_vtkImageRFFT(void);
extern SWIGEXPORT(void) Init_vtkImageRange3D(void);
extern SWIGEXPORT(void) Init_vtkImageResample(void);
extern SWIGEXPORT(void) Init_vtkImageSeparableConvolution(void);
extern SWIGEXPORT(void) Init_vtkImageSobel2D(void);
extern SWIGEXPORT(void) Init_vtkImageSobel3D(void);
extern SWIGEXPORT(void) Init_vtkImageCityBlockDistance(void);
extern SWIGEXPORT(void) Init_vtkImageFFT(void);
#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C"
#endif
SWIGEXPORT(void) Init_Imaging(void){

  Init_vtkImagingInstantiator();
  Init_vtkBooleanTexture();
  Init_vtkExtractVOI();
  Init_vtkGaussianSplatter();
  Init_vtkImageAccumulate();
  Init_vtkImageAppend();
  Init_vtkImageAppendComponents();
  Init_vtkImageBlend();
  Init_vtkImageButterworthHighPass();
  Init_vtkImageButterworthLowPass();
  Init_vtkImageCacheFilter();
  Init_vtkImageCanvasSource2D();
  Init_vtkImageCast();
  Init_vtkImageChangeInformation();
  Init_vtkImageCheckerboard();
  Init_vtkImageClip();
  Init_vtkImageConnector();
  Init_vtkImageConvolve();
  Init_vtkImageCorrelation();
  Init_vtkImageCursor3D();
  Init_vtkImageDataStreamer();
  Init_vtkImageDifference();
  Init_vtkImageDivergence();
  Init_vtkImageDotProduct();
  Init_vtkImageEllipsoidSource();
  Init_vtkImageEuclideanToPolar();
  Init_vtkImageExport();
  Init_vtkImageExtractComponents();
  Init_vtkImageGaussianSmooth();
  Init_vtkImageGaussianSource();
  Init_vtkImageGradient();
  Init_vtkImageGradientMagnitude();
  Init_vtkImageGridSource();
  Init_vtkImageHSIToRGB();
  Init_vtkImageHSVToRGB();
  Init_vtkImageIdealHighPass();
  Init_vtkImageIdealLowPass();
  Init_vtkImageImport();
  Init_vtkImageIslandRemoval2D();
  Init_vtkImageIterateFilter();
  Init_vtkImageLaplacian();
  Init_vtkImageLogarithmicScale();
  Init_vtkImageLogic();
  Init_vtkImageLuminance();
  Init_vtkImageMagnify();
  Init_vtkImageMagnitude();
  Init_vtkImageMandelbrotSource();
  Init_vtkImageMapToColors();
  Init_vtkImageMapToRGBA();
  Init_vtkImageMapToWindowLevelColors();
  Init_vtkImageMask();
  Init_vtkImageMaskBits();
  Init_vtkImageMathematics();
  Init_vtkImageNoiseSource();
  Init_vtkImageNonMaximumSuppression();
  Init_vtkImageNormalize();
  Init_vtkImageOpenClose3D();
  Init_vtkImagePadFilter();
  Init_vtkImageQuantizeRGBToIndex();
  Init_vtkImageRGBToHSI();
  Init_vtkImageRGBToHSV();
  Init_vtkImageRectilinearWipe();
  Init_vtkImageReslice();
  Init_vtkImageSeedConnectivity();
  Init_vtkImageShiftScale();
  Init_vtkImageShrink3D();
  Init_vtkImageSinusoidSource();
  Init_vtkImageSkeleton2D();
  Init_vtkImageSpatialFilter();
  Init_vtkImageStencil();
  Init_vtkImageStencilData();
  Init_vtkImageStencilSource();
  Init_vtkImageThreshold();
  Init_vtkImageToImageStencil();
  Init_vtkImageTranslateExtent();
  Init_vtkImageVariance3D();
  Init_vtkImageWrapPad();
  Init_vtkImplicitFunctionToImageStencil();
  Init_vtkPointLoad();
  Init_vtkSampleFunction();
  Init_vtkShepardMethod();
  Init_vtkSimpleImageFilterExample();
  Init_vtkSurfaceReconstructionFilter();
  Init_vtkTriangularTexture();
  Init_vtkVoxelModeller();
  Init_vtkImageAnisotropicDiffusion2D();
  Init_vtkImageAnisotropicDiffusion3D();
  Init_vtkImageConstantPad();
  Init_vtkImageContinuousDilate3D();
  Init_vtkImageContinuousErode3D();
  Init_vtkImageDecomposeFilter();
  Init_vtkImageDilateErode3D();
  Init_vtkImageEuclideanDistance();
  Init_vtkImageFlip();
  Init_vtkImageFourierCenter();
  Init_vtkImageFourierFilter();
  Init_vtkImageHybridMedian2D();
  Init_vtkImageMedian3D();
  Init_vtkImageMirrorPad();
  Init_vtkImagePermute();
  Init_vtkImageRFFT();
  Init_vtkImageRange3D();
  Init_vtkImageResample();
  Init_vtkImageSeparableConvolution();
  Init_vtkImageSobel2D();
  Init_vtkImageSobel3D();
  Init_vtkImageCityBlockDistance();
  Init_vtkImageFFT();
}
